@@ -18,11 +18,11 @@ Template::Flute - Modern designer-friendly HTML templating Engine
 
 =head1 VERSION
 
-Version 0.0107
+Version 0.0108
 
 =cut
 
-our $VERSION = '0.0107';
+our $VERSION = '0.0108';
 
 =head1 SYNOPSIS
 
@@ -520,15 +520,29 @@ sub _sub_process {
 
 		my $list = $template->{lists}->{$spec_name};
 		my $count = 1;
+        my $iter_records;
 
-        if ($records) {
+        if (defined blessed $records) {
+            # check whether this object can serve as iterator
+            if ($records->can('next') && $records->can('count')) {
+                $iter_records = $records;
+            }
+            else {
+                die "Object cannot be used as iterator for list $spec_name: ", ref($records);
+            }
+        }
+        else {
+            $iter_records = Template::Flute::Iterator->new(@$records);
+        }
+
+        if ($iter_records->count) {
             $list_active{$spec_name} = 1;
         }
         else {
             $list_active{$spec_name} = 0;
         }
 
-		for my $record_values (@$records){
+		while (my $record_values = $iter_records->next) {
 			my $element = $element_template->copy();
 			$element = $self->_sub_process($element, $sub_spec, $record_values, undef, undef, $count, $level + 1);
 
@@ -570,7 +584,7 @@ sub _sub_process {
             my $name = $spec_xml->att('name');
             my $parent_name = $elt->parent->att('name');
 
-            if (defined $name && $name ne $parent_name) {
+            if (! defined $name || $name ne $parent_name) {
                 # don't process params of sublists again
                 next;
             }
